import pkjs from "./package.json";
import { defineConfig } from "rollup";
import { nodeResolve } from "@rollup/plugin-node-resolve";
import alias from "@rollup/plugin-alias";
import { swc } from "rollup-plugin-swc3";
import { resolve as resolvePath } from "path";
import { visualizer } from "rollup-plugin-visualizer";

const projectRootDir = resolvePath(__dirname);

export default defineConfig({
	input: pkjs.main,
	output: {
		file: "dist/build.js",
		format: "iife"
	},
	external: ["React"],
	plugins: [
		alias({
			entries: [
				{
					find: "nests",
					replacement: resolvePath(
						projectRootDir,
						"node_modules/nests/esm/"
					)
				},
				{
					find: "react",
					replacement: resolvePath(
						projectRootDir,
						"src/shim_react.js"
					)
				}
			]
		}),
		nodeResolve(),
		swc({
			jsc: {
				minify: {
					compress: true
				},
				parser: {
					syntax: "ecmascript",
					jsx: true
				},
				target: "es2022",
				baseUrl: "./src"
			}
		}),
		visualizer()
	]
});
